@@ -1,4 +1,6 @@
 import os
+import shutil
+
 import urllib3
 import functools
 import platform
@@ -40,19 +42,75 @@ class ExecResult:
 
 class Server():
     def __init__(self,home="/home/my_home"):
+        """
+        初始化类实例，检查操作系统兼容性并创建指定的主目录
+
+        参数:
+            home: 主目录路径，默认为"/home/my_home"
+
+        异常:
+            RuntimeError: 当操作系统不支持或目录创建失败时抛出
+        """
+        # 检查操作系统平台
         self.__platform = platform.system()
-        if self.__platform == "linux":
-            log.info(f"Current platform is {self.__platform}.")
-        else:
-            raise RuntimeError(f"Currently do not support {self.__platform} only support linux.")
+        self.__validate_platform()
+
+        # 初始化并验证主目录
+        self.__home = self.__initialize_home_directory(home)
+
+    def __initialize_home_directory(self, home: str) -> str:
+        """
+        初始化主目录，确保目录存在
+
+        参数:
+            home: 要创建的主目录路径
+
+        返回:
+            成功创建的主目录路径
+
+        异常:
+            RuntimeError: 当目录创建失败时抛出
+        """
         try:
-            rs=self.exec_command(f"mkdir -p {home}")
-            if rs.exit_code != 0:
-                raise RuntimeError(f"failed to create home directory {home}, error message is {rs.stderr}")
-            self.__home=home
+            # 优先使用Python内置方法创建目录（更跨平台且安全）
+            if not self.__directory_exists(home):
+                log.info(f"开始创建主目录: {home}")
+                self.__create_directory(home)
+
+            # 验证目录是否成功创建
+            if not self.__directory_exists(home):
+                raise RuntimeError(f"主目录创建后验证失败: {home}不存在")
+
+            log.info(f"主目录初始化成功: {home}")
+            return home
+
         except Exception as e:
-            log.error(f"failed to create home directory {home}, error message is {e}")
-            raise e
+            error_msg = f"主目录创建失败: {str(e)}"
+            log.error(error_msg)
+            raise RuntimeError(error_msg) from e
+
+    def __validate_platform(self) -> None:
+        """验证操作系统是否为Linux，不支持则抛出异常"""
+        if self.__platform == "Linux":
+            log.info(f"当前操作系统: {self.__platform} (支持)")
+        else:
+            raise RuntimeError(
+                f"不支持的操作系统: {self.__platform}，仅支持Linux"
+            )
+
+    def __create_directory(self, path: str) -> None:
+        """使用Python内置方法创建目录（含父目录）"""
+        try:
+            # 使用exist_ok=True避免重复创建错误
+            shutil.os.makedirs(path, exist_ok=True)
+        except PermissionError:
+            raise RuntimeError(f"权限不足，无法创建目录: {path}")
+        except OSError as e:
+            raise RuntimeError(f"系统错误，创建目录失败: {path}, 错误: {str(e)}")
+
+    def __directory_exists(self, path: str) -> bool:
+        """检查目录是否存在且为有效目录"""
+        return shutil.os.path.exists(path) and shutil.os.path.isdir(path)
 
     @enter_and_leave_function
     def exec_command(self, command: Union[str, List[str]]) -> ExecResult:
